#!/bin/ksh93

# $Id: Build.sh 527 2012-10-13 05:28:29Z elkner $

# SRC:
# svn co https://svn.forgerock.org/opendj/tags/2.5.0-Xpress1
# svn co https://svn.forgerock.org/opendj/tags/2.5.0-Xpress1-docs

# Pre-Build: Choose SVR4
SRCURL=http://forgerock.org/opendj-archive.html

VERSION=2.5.0
SVERS=25						# just major+minor from $VERSION
SUBVERS='-Xpress1'

MEM_MODEL=32

SDIR=${.sh.file%/*}
SCRIPTDIR=${SDIR}/../../../etc
. ${SCRIPTDIR}/buildfunctions.sh

#SRC=$SOURCE/java
SRC=/net/isis.iws/export/downloads/forgerock/dj
TMPBUILD=$BUILD/opendj-${VERSION}

function doPrepare {
	#REQUIRED="LNFxf86 LNFglib2 LNFgtk+ LNFatk LNFpango LNFcairo LNFopenssl"
	#SUNPKGS="SUNWzlib SUNWfontconfig SUNWfreetype2"
	REQUIRED=""
	
	. ${SCRIPTDIR}/root4build

	unzip -q -d $TMPBUILD ${SRC}/opendj-${VERSION}${SUBVERS}.zip
	cd $TMPBUILD
#	for p in ${SDIR}/*.patch ; do
#		gpatch -p1 -b -z .orig <$p
#	done
}

function doMake {
	cd $TMPBUILD

	echo "make log goes to $MAKELOG"
	[[ -d classes ]] && rm -rf classes
	mkdir classes
	typeset JH=${JAVA_1_6_HOME}
	typeset CP="${TMPBUILD}/opendj/reloc/opendj/lib/OpenDJ.jar"

	cp ${CP} .
	CP+=":${JH}/jre/lib/javaws.jar"
	javac -cp "$CP" -g -source 1.6 -target 1.6 -Xprefer:source -Xlint:all -O \
		-bootclasspath "${JH}/jre/lib/rt.jar:${JH}/jre/lib/jsse.jar:${JH}/jre/lib/jce.jar" \
		-d classes ${SDIR}/src/*.java

	jar uvf OpenDJ.jar -C ${TMPBUILD}/classes .
	jar i OpenDJ.jar

	[[ -d ${TMPBUILD}/man ]] && rm -rf ${TMPBUILD}/man
	mkdir ${TMPBUILD}/man
	cd ${TMPBUILD}/man
	cp ${SDIR}/docs/*.xml .
	gsed -i -e "s,@VERS@,$SVERS,g" \
		-e "/docTargetVersion/ s,<?eval \${docTargetVersion}?>,${VERSION}," \
		-e "s,@PRODUCT@,OpenDJ ${VERSION}${SUBVERS}," man-*.xml common.xml
	MXSL=/usr/share/sgml/docbook/xsl-stylesheets/manpages/profile-docbook.xsl
	#MXSL=${DOCBOOK_XSL_HOME}/manpages/profile-docbook.xsl
	for X in man-*.xml ; do
		xsltproc --xinclude --stringparam "profile.os" "solaris" \
			--param man.authors.section.enabled 0 \
			--param man.copyright.section.enabled 0 \
			--param man.hyphenate 1 \
			--param man.justify 1 \
			--param refentry.meta.get.quietly 1 \
			${MXSL} $X
	done
	# remove stupid groff links
	gsed -i -r -e '/\[blue\]/ s,\\m\[blue\](.*)\\m\[\],\1,' \
		-e '/\\s-2\\u/ s,\\s-2\\u(\[[0-9]+\])\\d\\s\+2, \1,' \
		-e '/^\.sp \./ s,^.*,.sp,' *.1M *.5
}

function installOpenDJ {
	typeset PROF='OpenDJ Admin'
	typeset CLIENT_SCRIPT='base64 control-panel dsconfig dsframework dsjavaproperties ldapcompare ldapdelete ldapmodify ldappasswordmodify ldapsearch manage-account manage-tasks status'	# create-rc-script
	typeset SERVER_SCRIPT='dbtest dsreplication encode-password ldif-diff ldifmodify ldifsearch list-backends make-ldif rebuild-index verify-index'
	typeset MIXED_SCRIPT='backup export-ldif import-ldif restore'

	# this is just pkg content, so it does not include any links, special files
	mkdir ${PROTO}/opt
	cp -pr opendj/reloc/opendj ${PROTO}/opt/opendj${SVERS} || exit 1
	cp -p opendj/install/copyright ${PROTO}/opt/opendj${SVERS}/legal-notices/
	cp OpenDJ.jar ${PROTO}/opt/opendj${SVERS}/lib/

	cd $PROTO/opt/opendj${SVERS} || exit 1

	# remove obsolete stuff
	rm -rf bin/create-rc-script lib/_svc-opendj.sh resources \
		man/man1/{create-rc-script.1,uninstall.1}
	rm legal-notices/CDDLv1_0.txt
	mv legal-notices/OpenDS.LICENSE legal-notices/OpenDJ.LICENSE

	cd ${PROTO}
	mkdir -p etc/security/{exec_attr.d,prof_attr.d,auth_attr.d}
	print "${PROF}:RO::OpenDJ Server scripts, commands and services:auths=solaris.smf.manage.opendj,solaris.smf.value.opendj" \
		>etc/security/prof_attr.d/opendj
	print 'solaris.smf.manage.opendj:RO::OpenDJ Service Management::
solaris.smf.value.opendj:RO::Change Values of OpenDJ Service Properties::' \
		>etc/security/auth_attr.d/opendj

	typeset X EXEC=''
	typeset -n DJSCRIPTS
	typeset -l DST
	for DJSCRIPTS in CLIENT_SCRIPT SERVER_SCRIPT MIXED_SCRIPT ; do
		DST=${!DJSCRIPTS//_/-}
		for X in ${DJSCRIPTS} ; do
			ln -sf ../lib/_${DST}.sh opt/opendj${SVERS}/bin/"$X"
		done
		EXEC+="${PROF}:solaris:cmd:RO::/opt/opendj${SVERS}/lib/_${DST}.sh:uid=ldapd;gid=ldapd\n"
	done
	for X in 'setup' 'bin/start-ds' ; do
		EXEC+="${PROF}:solaris:cmd:RO::/opt/opendj${SVERS}/${X}:uid=ldapd;gid=ldapd;privs=basic,net_privaddr\n"
	done
	for X in 'bin/stop-ds' 'unconfigure' 'lib/_cptmpl_script.sh'
	do
		EXEC+="${PROF}:solaris:cmd:RO::/opt/opendj${SVERS}/${X}:uid=ldapd;gid=ldapd\n"
	done
	print -n "${EXEC}" >etc/security/exec_attr.d/opendj${SVERS}

	mkdir -p lib/svc/{method,manifest/network/ldap}
	for X in opendj.method opendj.manifest ; do
		[[ ${X##*.} == 'method' ]] \
			&& DST=lib/svc/method/${.sh.match%.}$SVERS \
			|| DST=lib/svc/manifest/network/ldap/${.sh.match%.}${SVERS}.xml
		gsed -e "s,@VERS@,${SVERS},g" ${SDIR}/$X >"$DST"
	done
	# IPS supports no relocation
	[[ -d ${TMPBUILD}/svc.d ]] && rm -rf ${TMPBUILD}/svc.d
	mkdir ${TMPBUILD}/svc.d
	cp -pr lib/* ${TMPBUILD}/svc.d/
	gsed -i -e 's,@CLIENT_BASEDIR@,/opt,g' lib/svc/manifest/network/ldap/* \
		lib/svc/method/*

	cd opt/opendj${SVERS}/tmpl_instance
	typeset EMPTY_DIRS='bak changelogDb classes config/schema db import-tmp ldif lib/extensions locks logs history'
	for X in ${EMPTY_DIRS} ; do
		[[ ! -d $X ]] && mkdir -p $X
	done

	cd $SDIR/scripts || exit 1
	cp -r * $PROTO/opt/opendj${SVERS}/
	gsed -i -e "s,@VERS@,${SVERS},g" \
		$PROTO/opt/opendj${SVERS}/{lib/_script-util.sh,configure,unconfigure}

	rm -rf $PROTO/opt/opendj${SVERS}/man/*
	mkdir -p $PROTO/opt/opendj${SVERS}/man/{man1m,man5}
	ksh $PROTO/opt/opendj${SVERS}/configure '--nroff' \
		2>$PROTO/opt/opendj${SVERS}/man/man1m/configure.1m
	ksh $PROTO/opt/opendj${SVERS}/unconfigure '--nroff' \
		2>$PROTO/opt/opendj${SVERS}/man/man1m/unconfigure.1m
	cd ${TMPBUILD}/man
	for X in *.1M ; do
		cp $X $PROTO/opt/opendj${SVERS}/man/man1m/${X%M}m
	done
	cp *.5 $PROTO/opt/opendj${SVERS}/man/man5/

	gsed -i \
		-e '/^# start-ds.java-args/ s,^#.*,start-ds.java-args=-server -d64 -Xms256m -XX:+UseCompressedOops -Duser.language=en -Duser.country=US,' \
		-e '/^start-ds/ a \# For big|production servers\n#start-ds.java-args=-server -d64 -Xms2G -Xmx2G -XX:+UseCompressedOops -XX:+UseConcMarkSweepGC -XX:NewSize=512M -Duser.language=en -Duser.country=US' \
		-e '/^# import-ldif.*-server/ s,^# \(.*\),\1 -d64,' \
		$PROTO/opt/opendj${SVERS}/tmpl_instance/config/java.properties
}

function doPackage {
	cd $TMPBUILD
	clean_dst $PROTO

	installOpenDJ

	cd $TMPBUILD
	PKG_VERS=$(< opendj/reloc/opendj/tmpl_instance/config/buildinfo )
	X=${PKG_VERS%.*}
	X+=" (${.sh.match#.})"
	pkginfo2arch
	createIPS -a "i386 sparc" -p "network/ldap/opendj25" \
		-V "OpenDJ${SUBVERS} ${X}" \
		-c "System/Administration and Configuration" \
		-s $SRCURL

	cat>${TMPBUILD}/prototype.lnf<<EOF
!default 0755 bin bin
i pkginfo=${TMPBUILD}/pkginfo.lnf
i depend=${SDIR}/depend
i i.rename=${SCRIPTDIR}/i.rename
i i.manifest=${SCRIPTDIR}/i.manifest
i r.manifest=${SCRIPTDIR}/r.manifest
i checkinstall=${SDIR}/checkinstall
i copyright=${SDIR}/copyright
d none /var ? ? ?
d none /var/share ? ? ?
d none /var/share/ldap 0755 ldapd ldapd
d none /var/share/ldap/opendj 0755 ldapd ldapd
d none /etc ? ? ?
d none /etc/security ? ? ?
EOF
	pkgproto ${TMPBUILD}/svc.d=/lib ${PROTO}/opt/= | nawk '{
		if ( $1 == "l" || $1 == "s" ) {
			print
		} else if ( $1 == "d" ) {
			if ( $3 ~ "^/lib" || $3 ~ "^/var" ) {
				print $1, $2, $3, "0755 ? ?"
			} else {
				print $1, $2, $3, "0755 bin bin"
			}
		} else if ( $3 ~ "^/lib/svc/method" ) {
			print $1, "rename", $3, "0555 root bin"
		} else if ( $3 ~ "^/lib/svc/manifest" ) {
			print $1, "manifest", $3, "0444 root sys"
		} else if ( $3 ~ "lib/.*.sh" || $3 ~ "/bin/" || $3 ~ "configure|setup|unconfigure|upgrade" ) {
			print $1, $2, $3, "0755 bin bin"
		} else {
			print $1, $2, $3, "0644 bin bin"
		}
	}' >>${TMPBUILD}/prototype.lnf

	if [[ ! -d /lib/svc/manifest ]]; then # S10
		gsed -i -e 's, /lib/svc/manifest, /var/svc/manifest,' \
			${TMPBUILD}/prototype.lnf
		print 'd none /var/svc ? ? ?' >>${TMPBUILD}/prototype.lnf
	fi

	addRBAC -p /opt ${PROTO}/etc/security/exec_attr.d/* \
		${PROTO}/etc/security/prof_attr.d/* ${PROTO}/etc/security/auth_attr.d/*

	echo "calling ${TMPBUILD}/prototype.lnf"
	call_pkgmk ${TMPBUILD}/prototype.lnf
}

doBuild "$@"
