#!/bin/ksh93
#
# $Id: _mixed-script.sh 553 2013-04-13 17:41:34Z elkner $
#
# CDDL HEADER START
#
# The contents of this file are subject to the terms of the
# Common Development and Distribution License, Version 1.0 only
# (the "License").  You may not use this file except in compliance
# with the License.
#
# You can obtain a copy of the license at
# trunk/opends/resource/legal-notices/OpenDS.LICENSE
# or https://OpenDS.dev.java.net/OpenDS.LICENSE.
# See the License for the specific language governing permissions
# and limitations under the License.
#
# When distributing Covered Code, include this CDDL HEADER in each
# file and include the License file at
# trunk/opends/resource/legal-notices/OpenDS.LICENSE.  If applicable,
# add the following below this CDDL HEADER, with the fields enclosed
# by brackets "[]" replaced with your own identifying information:
#      Portions Copyright [yyyy] [name of copyright owner]
#
# CDDL HEADER END
#
#
#      Copyright 2008-2010 Sun Microsystems, Inc.
#      Portions Copyright 2011 ForgeRock AS
#      Portions Copyright 2013 Jens Elkner

# This script is used to invoke processes that might be run on server or
# in client mode (depending on the state of the server and the arguments
# passed).  It should not be invoked directly by end users.

# Capture the location of this script and the Directory Server install
# and instance  root so that we can use them to create appropriate paths.

[[ ${FNTRACE} == 'ALL' || ${FNTRACE} == 'main' ]] && set -x
INSTALL_ROOT="${.sh.file%/*/*}"

if [[ -z ${OPENDJ_INVOKE_CLASS} || -z ${SCRIPT_NAME} ]]; then
	SCRIPT_NAME=${.sh.file##*/}
	OIC=''
	case "$SCRIPT_NAME" in
		restore)
			# perform a restore of a Directory Server backend
			OIC='org.opends.server.tools.RestoreDB'
			;;
		export-ldif)
			# perform an LDIF export for a Directory Server
			OIC='org.opends.server.tools.ExportLDIF'
			;;
		backup)
			# perform a backup of a Directory Server backend
			OIC='org.opends.server.tools.BackUpDB'
			;;
		import-ldif)
			# import LDIF data into a Directory Server backend
			OIC='org.opends.server.tools.ImportLDIF'
			;;
	esac
	OPENDJ_INVOKE_CLASS=${OIC}
fi

if [[ -z ${OPENDJ_INVOKE_CLASS} ]]; then
	print -u2 'ERROR:  OPENDJ_INVOKE_CLASS environment variable is not set.'
	exit 1
fi

# We keep this values to reset the environment before calling _script-util.sh
# for the second time.
OLD_SCRIPT_NAME=${SCRIPT_NAME}

ORIGINAL_JAVA_ARGS=${OPENDJ_JAVA_ARGS}
ORIGINAL_JAVA_HOME=${OPENDJ_JAVA_HOME}
ORIGINAL_JAVA_BIN=${OPENDJ_JAVA_BIN}

# Set environment variables
. "${INSTALL_ROOT}"/lib/_script-util.sh
checkEnv 'set-full-environment'
NO_CHECK=1 checkInstance "$@"

MUST_CALL_AGAIN=0
SCRIPT_NAME=${OLD_SCRIPT_NAME}.online
SCRIPT_NAME_ARG="-Dorg.opends.server.scriptName=${OLD_SCRIPT_NAME}"

# Check whether is local or remote
"${OPENDJ_JAVA_BIN}" ${OPENDJ_JAVA_ARGS} ${SCRIPT_ARGS}  ${SCRIPT_NAME_ARG} \
	-Dorg.opends.quicksetup.Root="${INSTALL_ROOT}" \
	-Dorg.opends.server.InstanceRoot="${INSTANCE_ROOT}" \
	${OPENDJ_INVOKE_CLASS} \
	--configClass org.opends.server.extensions.ConfigFileHandler \
	--configFile "${INSTANCE_ROOT}"/config/config.ldif --testIfOffline "$@"
RC=$?
if (( ${RC} == 51 )); then
	# Set the original values that the user had on the environment in order to
	# be sure that the script works with the proper arguments (in particular
	# if the user specified not to overwrite the environment).
	OPENDJ_JAVA_ARGS=${ORIGINAL_JAVA_ARGS}
	OPENDJ_JAVA_HOME=${ORIGINAL_JAVA_HOME}
	OPENDJ_JAVA_BIN=${ORIGINAL_JAVA_BIN}

	# Set the environment to use the offline properties
	SCRIPT_NAME=${OLD_SCRIPT_NAME}.offline
	checkEnv 'set-full-environment'
	NO_CHECK=0 checkInstance "$@"
	MUST_CALL_AGAIN=1
elif (( ${RC} == 52 )); then
	MUST_CALL_AGAIN=1
else
	# This is likely a problem with the provided arguments.
	exit ${RC}
fi

if (( ${MUST_CALL_AGAIN} )); then
	# Launch the server utility.
	"${OPENDJ_JAVA_BIN}" ${OPENDJ_JAVA_ARGS} ${SCRIPT_ARGS} ${SCRIPT_NAME_ARG} \
		-Dorg.opends.quicksetup.Root="${INSTALL_ROOT}" \
		-Dorg.opends.server.InstanceRoot="${INSTANCE_ROOT}" \
		${OPENDJ_INVOKE_CLASS} \
		--configClass org.opends.server.extensions.ConfigFileHandler \
		--configFile "${INSTANCE_ROOT}"/config/config.ldif "$@"
fi
