#!/bin/ksh93
#
# $Id: _server-script.sh 554 2013-04-22 09:12:58Z elkner $
#
# CDDL HEADER START
#
# The contents of this file are subject to the terms of the
# Common Development and Distribution License, Version 1.0 only
# (the "License").  You may not use this file except in compliance
# with the License.
#
# You can obtain a copy of the license at
# trunk/opends/resource/legal-notices/OpenDS.LICENSE
# or https://OpenDS.dev.java.net/OpenDS.LICENSE.
# See the License for the specific language governing permissions
# and limitations under the License.
#
# When distributing Covered Code, include this CDDL HEADER in each
# file and include the License file at
# trunk/opends/resource/legal-notices/OpenDS.LICENSE.  If applicable,
# add the following below this CDDL HEADER, with the fields enclosed
# by brackets "[]" replaced with your own identifying information:
#      Portions Copyright [yyyy] [name of copyright owner]
#
# CDDL HEADER END
#
#
#      Copyright 2006-2010 Sun Microsystems, Inc.
#      Portions Copyright 2011 ForgeRock AS
#      Portions Copyright 2013 Jens Elkner

# This script is used to invoke various server-side processes.  It should not
# be invoked directly by end users.

[[ ${FNTRACE} == 'ALL' || ${FNTRACE} == 'main' ]] && set -x
INSTALL_ROOT="${.sh.file%/*/*}"

typeset -a MISC_ARGS=( )
if [[ -z ${OPENDJ_INVOKE_CLASS} || -z ${SCRIPT_NAME} ]]; then
	OIC=''
	SCRIPT_NAME=${.sh.file##*/}
	case "$SCRIPT_NAME" in
		encode-password)
			# encode clear-text passwords or verify whether a given clear-text
			# password matches a provided encoded password
			OIC='org.opends.server.tools.EncodePassword'
			;;
		make-ldif)
			# generate LDIF data based on a provided template
			NO_CHECK=1
			MISC_ARGS+=( '--resourcePath' "${INSTANCE_ROOT}/config/MakeLDIF" )
			OIC='org.opends.server.tools.makeldif.MakeLDIF'
			;;
		ldif-diff)
			# compare the contents of two LDIF files
			OIC='org.opends.server.tools.LDIFDiff'
			;;
		dbtest)
			# debug JE backends in the Directory Server
			OIC='org.opends.server.tools.DBTest'
			;;
		ldifmodify)
			# alter the contents of an LDIF file
			OIC='org.opends.server.tools.LDIFModify'
			;;
		list-backends)
			# perform a restore of a Directory Server backend
			OIC='org.opends.server.tools.ListBackends'
			;;
		rebuild-index)
			# rebuild the contents of a Directory Server backend storing its
			# data in the Berkeley DB Java Edition
			OIC='org.opends.server.tools.RebuildIndex'
			;;
		verify-index)
			# perform validation on the contents of a Directory Server backend
			# storing its data in the Berkeley DB Java Edition
			OIC='org.opends.server.tools.VerifyIndex'
			;;
		dsreplication)
			# perform some replication specific operations
			OIC='org.opends.server.tools.dsreplication.ReplicationCliMain'
			if [[ ${RECURSIVE_LOCAL_CALL} != 'true' ]]; then
				SCRIPT_ARGS+='-Dorg.opends.server.dsreplicationcallstatus=firstcall'
			else
				SCRIPT_NAME='dsreplication.offline'
				SCRIPT_ARGS=${SCRIPT_ARGS//-Dorg.opends.server.dsreplicationcallstatus=firstcall}
			fi
			;;
		ldifsearch)
			# perform searches in an LDIF file
			OIC='org.opends.server.tools.LDIFSearch'
			;;
	esac
	OPENDJ_INVOKE_CLASS=${OIC}
fi

if [[ -z ${OPENDJ_INVOKE_CLASS} ]]; then
	print -u2 'ERROR:  OPENDJ_INVOKE_CLASS environment variable is not set.'
	exit 1
fi

# Set environment variables
. "${INSTALL_ROOT}/lib/_script-util.sh"
checkEnv 'set-full-environment'
checkInstance "$@"

# Launch the appropriate server utility.
"${OPENDJ_JAVA_BIN}" ${OPENDJ_JAVA_ARGS} ${SCRIPT_ARGS} ${SCRIPT_NAME_ARG} \
	-Dorg.opends.quicksetup.Root="${INSTALL_ROOT}" \
	-Dorg.opends.server.InstanceRoot="${INSTANCE_ROOT}" \
	${OPENDJ_INVOKE_CLASS} \
	--configClass org.opends.server.extensions.ConfigFileHandler \
	--configFile "${INSTANCE_ROOT}"/config/config.ldif "${MISC_ARGS[@]}" "$@"
